nbxmpp.idlequeue.SelectIdleQueue

Package nbxmpp :: Module idlequeue :: Class SelectIdleQueue |
[hide private]
[frames] | no frames]

# Class SelectIdleQueue

source code

Extends IdleQueue to use select.select() for polling

This class exisists for the sake of gtk2.8 on windows, which doesn't seem to support io_add_watch properly (yet)

Instance Methods | [hide private]
_init_idle(self) Create a dict, which maps file/pipe/sock descriptor to glib event id | source code
_add_idle(self, fd, flags) This method is called when we plug a new idle object. Remove descriptor to read/write/error lists, according flags | source code
_remove_idle(self, fd) This method is called when we unplug a new idle object. Remove descriptor from read/write/error lists | source code
process(self) Process idlequeue. Check for any pending timeout or alarm events. Call IdleObjects on possible and requested read, write and error events on their file descriptors | source code
Inherited from `IdleQueue`: `__init__`, `current_time`, `plug_idle`, `remove_alarm`, `remove_timeout`, `set_alarm`, `set_read_timeout`, `unplug_idle` Inherited from `IdleQueue` (private): `_check_time_events`, `_process_events`

Class Variables | [hide private]
Inherited from `IdleQueue`: `PROCESS_TIMEOUT`

Method Details | [hide private]

### _init_idle(self) | source code
Create a dict, which maps file/pipe/sock descriptor to glib event id Overrides: IdleQueue._init_idle

### _add_idle(self, fd, flags) | source code
This method is called when we plug a new idle object. Remove descriptor to read/write/error lists, according flags Overrides: IdleQueue._add_idle

### _remove_idle(self, fd) | source code
This method is called when we unplug a new idle object. Remove descriptor from read/write/error lists Overrides: IdleQueue._remove_idle

### process(self) | source code
Process idlequeue. Check for any pending timeout or alarm events. Call IdleObjects on possible and requested read, write and error events on their file descriptors Call this in regular intervals. Overrides: IdleQueue.process (inherited documentation)